@@ -33,7 +33,6 @@ clish_command_diff(const clish_command_t * cmd1, const clish_command_t * cmd2);
 void clish_command_delete(clish_command_t *instance);
 void clish_command_insert_param(clish_command_t *instance,
 	clish_param_t *param);
-int clish_command_help(const clish_command_t *instance);
 void clish_command_dump(const clish_command_t *instance);
 
 _CLISH_GET_STR(command, name);
@@ -76,5 +75,6 @@ int clish_command__get_depth(const clish_command_t * instance);
 clish_view_restore_e clish_command__get_restore(const clish_command_t * instance);
 const clish_command_t * clish_command__get_orig(const clish_command_t * instance);
 const clish_command_t * clish_command__get_cmd(const clish_command_t * instance);
+bool_t clish_command_is_incomplete(const clish_command_t *instance);
 
 #endif				/* _clish_command_h */
