@@ -4,9 +4,6 @@
 
 #include "clish/command.h"
 
-/*---------------------------------------------------------
- * PRIVATE TYPES
- *--------------------------------------------------------- */
 struct clish_command_s {
 	lub_bintree_node_t bt_node;
 	char *name;
@@ -25,7 +22,6 @@ struct clish_command_s {
 	char *alias_view;
 	char *alias;
 	clish_view_t *pview;
-	bool_t lock;
-	bool_t interrupt;
 	bool_t dynamic; /* Is command dynamically created */
+	bool_t internal; /* Is command internal? Like the "startup" */
 };
