@@ -89,12 +89,22 @@ _CLISH_SET_STR_ONCE(ptype, text);
 _CLISH_GET_STR(ptype, text);
 _CLISH_SET_STR_ONCE(ptype, completion);
 _CLISH_GET_STR(ptype, completion);
+_CLISH_GET(ptype, clish_ptype_preprocess_e, preprocess);
 _CLISH_SET_ONCE(ptype, clish_ptype_preprocess_e, preprocess);
 _CLISH_GET_STR(ptype, range);
 _CLISH_GET(ptype, clish_action_t *, action);
+_CLISH_GET_STR(ptype, pattern);
 _CLISH_GET(ptype, clish_ptype_method_e, method);
 
 void clish_ptype__set_pattern(clish_ptype_t * instance,
 	const char *pattern, clish_ptype_method_e method);
 
+const char *clish_ptype_method__get_name(clish_ptype_method_e
+	method);
+clish_ptype_method_e clish_ptype_method_resolve(const char *name);
+
+const char *clish_ptype_preprocess__get_name(clish_ptype_preprocess_e
+	preprocess);
+clish_ptype_preprocess_e clish_ptype_preprocess_resolve(const char *name);
+
 #endif	/* _clish_ptype_h */
