@@ -15,7 +15,7 @@ void clish_ptype_dump(clish_ptype_t * this)
 	lub_dump_printf("text       : %s\n", LUB_DUMP_STR(clish_ptype__get_text(this)));
 	lub_dump_printf("pattern    : %s\n", LUB_DUMP_STR(this->pattern));
 	lub_dump_printf("method     : %s\n",
-		clish_ptype__get_method_name(this->method));
+		clish_ptype_method__get_name(this->method));
 	lub_dump_printf("postprocess: %s\n",
 		clish_ptype_preprocess__get_name(this->preprocess));
 	lub_dump_undent();
