@@ -54,6 +54,7 @@ void clish_context__set_pargv(void *instance, clish_pargv_t *pargv);
 clish_pargv_t *clish_context__get_pargv(const void *instance);
 void clish_context__set_action(void *instance, const clish_action_t *action);
 const clish_action_t *clish_context__get_action(const void *instance);
+bool_t clish_context__get_expand(const clish_context_t *context);
 _END_C_DECL
 
 /* Shell */
@@ -98,6 +99,8 @@ clish_ptype_t *clish_shell_find_create_ptype(clish_shell_t *instance,
 	const char *pattern,
 	clish_ptype_method_e method,
 	clish_ptype_preprocess_e preprocess);
+clish_view_t *clish_shell_find_view(clish_shell_t * instance,
+	const char *name);
 clish_ptype_t *clish_shell_find_ptype(clish_shell_t *instance,
 	const char *name);
 void clish_shell_help(clish_shell_t * instance, const char *line);
@@ -119,7 +122,6 @@ int clish_shell_push_file(clish_shell_t * instance, const char * fname,
 	bool_t stop_on_error);
 int clish_shell_push_fd(clish_shell_t * instance, FILE * file,
 	bool_t stop_on_error);
-void clish_shell_insert_var(clish_shell_t *instance, clish_var_t *var);
 clish_var_t *clish_shell_find_var(clish_shell_t *instance, const char *name);
 char *clish_shell_expand_var(const char *name, clish_context_t *context);
 char *clish_shell_expand_var_ex(const char *name, clish_context_t *context, clish_shell_expand_e flags);
@@ -135,6 +137,8 @@ _CLISH_SET_STR(shell, lockfile);
 _CLISH_GET_STR(shell, lockfile);
 _CLISH_SET_STR(shell, default_shebang);
 _CLISH_GET_STR(shell, default_shebang);
+_CLISH_SET(shell, bool_t, default_expand);
+_CLISH_GET(shell, bool_t, default_expand);
 _CLISH_SET(shell, unsigned int, idle_timeout);
 _CLISH_SET(shell, unsigned int, wdog_timeout);
 _CLISH_GET(shell, unsigned int, wdog_timeout);
@@ -188,6 +192,7 @@ int clish_shell_wdog(clish_shell_t *instance);
 int clish_shell__save_history(const clish_shell_t *instance, const char *fname);
 int clish_shell__restore_history(clish_shell_t *instance, const char *fname);
 void clish_shell__stifle_history(clish_shell_t *instance, unsigned int stifle);
+char *clish_shell_format_username(const clish_shell_t *instance);
 
 /* Plugin functions */
 clish_plugin_t * clish_shell_create_plugin(clish_shell_t *instance,
@@ -222,6 +227,12 @@ int clish_shell__set_udata(clish_shell_t *instance,
 /* Access functions */
 int clish_shell_prepare(clish_shell_t *instance);
 
+/* Machine/Human oriented protocol */
+bool_t clish_shell_is_machine_interface(const clish_shell_t *shell);
+void clish_shell_set_machine_interface(clish_shell_t *shell);
+void clish_shell_set_human_interface(clish_shell_t *shell);
+void clish_shell_machine_retval(clish_shell_t *shell, int retval);
+
 /*
  * Non shell specific functions.
  * Start and Stop XML parser engine.
