@@ -8,6 +8,7 @@
 #include <ctype.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <pwd.h>
 
 #include "lub/string.h"
 #include "lub/conv.h"
@@ -75,7 +76,55 @@ static char *find_context_var(const char *name, clish_context_t *this)
 		tmp[sizeof(tmp) - 1] = '\0';
 		result = strdup(tmp);
 
-	} else if (!this->cmd) { /* The vars dependent on command */
+	} else if (!lub_string_nocasecmp(name, "_interactive")) {
+		if (clish_shell__get_interactive(this->shell) &&
+			tinyrl__get_isatty(this->shell->tinyrl))
+			result = strdup("1");
+		else
+			result = strdup("0");
+
+	} else if (!lub_string_nocasecmp(name, "_isatty")) {
+		if (tinyrl__get_isatty(this->shell->tinyrl))
+			result = strdup("1");
+		else
+			result = strdup("0");
+
+	} else if (!lub_string_nocasecmp(name, "_machine_interface")) {
+		if (clish_shell_is_machine_interface(this->shell))
+			result = strdup("1");
+		else
+			result = strdup("0");
+
+	} else if (!lub_string_nocasecmp(name, "_pid")) {
+		char tmp[10];
+		snprintf(tmp, sizeof(tmp), "%u", getpid());
+		tmp[sizeof(tmp) - 1] = '\0';
+		result = strdup(tmp);
+
+	} else if (!lub_string_nocasecmp(name, "_cur_depth")) {
+		char tmp[10];
+		int depth = clish_shell__get_depth(shell);
+		snprintf(tmp, sizeof(tmp), "%u", depth);
+		tmp[sizeof(tmp) - 1] = '\0';
+		result = strdup(tmp);
+
+	} else if (!lub_string_nocasecmp(name, "_cur_pwd")) {
+		int depth = clish_shell__get_depth(shell);
+		result = clish_shell__get_pwd_full(shell, depth);
+
+	} else if (!lub_string_nocasecmp(name, "_uid")) {
+		char tmp[10];
+		snprintf(tmp, sizeof(tmp), "%u", getuid());
+		tmp[sizeof(tmp) - 1] = '\0';
+		result = strdup(tmp);
+
+	} else if (!lub_string_nocasecmp(name, "_user")) {
+		result = clish_shell_format_username(shell);
+
+	/* The vars dependent on command. Code supposes this->cmd is valid.
+	 * Don't put command-independent variables after that line.
+	 */
+	} else if (!this->cmd) {
 		return NULL;
 
 	} else if (!lub_string_nocasecmp(name, "_full_cmd")) {
@@ -99,25 +148,6 @@ static char *find_context_var(const char *name, clish_context_t *this)
 		if (this->pargv)
 			result = clish_shell__get_params(this);
 
-	} else if (!lub_string_nocasecmp(name, "_interactive")) {
-		if (clish_shell__get_interactive(this->shell) &&
-			tinyrl__get_isatty(this->shell->tinyrl))
-			result = strdup("1");
-		else
-			result = strdup("0");
-
-	} else if (!lub_string_nocasecmp(name, "_isatty")) {
-		if (tinyrl__get_isatty(this->shell->tinyrl))
-			result = strdup("1");
-		else
-			result = strdup("0");
-
-	} else if (!lub_string_nocasecmp(name, "_pid")) {
-		char tmp[10];
-		snprintf(tmp, sizeof(tmp), "%u", getpid());
-		tmp[sizeof(tmp) - 1] = '\0';
-		result = strdup(tmp);
-
 	} else if (lub_string_nocasestr(name, "_prefix") == name) {
 		unsigned int idx = 0;
 		unsigned int pnum = 0;
@@ -132,16 +162,6 @@ static char *find_context_var(const char *name, clish_context_t *this)
 			lub_argv_delete(argv);
 		}
 
-	} else if (!lub_string_nocasecmp(name, "_cur_depth")) {
-		char tmp[10];
-		int depth = clish_shell__get_depth(shell);
-		snprintf(tmp, sizeof(tmp), "%u", depth);
-		tmp[sizeof(tmp) - 1] = '\0';
-		result = strdup(tmp);
-
-	} else if (!lub_string_nocasecmp(name, "_cur_pwd")) {
-		int depth = clish_shell__get_depth(shell);
-		result = clish_shell__get_pwd_full(shell, depth);
 	}
 
 	return result;
@@ -505,9 +525,7 @@ char *clish_shell_expand_var_ex(const char *name, clish_context_t *context, clis
 
 	/* try and substitute a parameter value */
 	if (pargv && (flags & SHELL_EXPAND_PARAM)) {
-		const clish_parg_t *parg = clish_pargv_find_arg(pargv, name);
-		if (parg)
-			tmp = clish_parg__get_value(parg);
+		tmp = clish_pargv_find_value(pargv, name);
 	}
 
 	/* try and substitute the param's default */
@@ -537,3 +555,5 @@ char *clish_shell_expand_var_ex(const char *name, clish_context_t *context, clis
 }
 
 /*----------------------------------------------------------- */
+CLISH_SET(shell, bool_t, default_expand);
+CLISH_GET(shell, bool_t, default_expand);
