@@ -72,6 +72,11 @@ static clish_xml_cb_t xml_elements[] = {
  * if CLISH_PATH is unset in the environment then this is the value used. 
  */
 const char *default_path = "/etc/clish;~/.clish";
+#ifdef WIN32
+const char *path_separators = ";";
+#else
+const char *path_separators = ":;";
+#endif
 
 static int process_node(clish_shell_t *shell, clish_xmlnode_t *node,
 	void *parent);
@@ -80,12 +85,12 @@ static int process_node(clish_shell_t *shell, clish_xmlnode_t *node,
 int clish_shell_load_scheme(clish_shell_t *this, const char *xml_path, const char *xslt_path)
 {
 	const char *path = xml_path;
-	char *buffer;
-	char *dirname;
+	char *buffer = NULL;
+	char *dirname = NULL;
 	char *saveptr = NULL;
 	int res = -1;
 	clish_xmldoc_t *doc = NULL;
-	DIR *dir;
+	DIR *dir = NULL;
 
 #ifdef HAVE_LIB_LIBXSLT
 	clish_xslt_t *xslt = NULL;
@@ -109,9 +114,9 @@ int clish_shell_load_scheme(clish_shell_t *this, const char *xml_path, const cha
 	buffer = lub_system_tilde_expand(path);
 
 	/* Loop though each directory */
-	for (dirname = strtok_r(buffer, ";", &saveptr);
-		dirname; dirname = strtok_r(NULL, ";", &saveptr)) {
-		struct dirent *entry;
+	for (dirname = strtok_r(buffer, path_separators, &saveptr);
+		dirname; dirname = strtok_r(NULL, path_separators, &saveptr)) {
+		struct dirent *entry = NULL;
 
 		/* Search this directory for any XML files */
 		dir = opendir(dirname);
@@ -179,6 +184,7 @@ int clish_shell_load_scheme(clish_shell_t *this, const char *xml_path, const cha
 			root = clish_xmldoc_get_root(doc);
 			r = process_node(this, root, NULL);
 			clish_xmldoc_release(doc);
+			doc = NULL;
 
 			/* Error message */
 			if (r) {
@@ -190,6 +196,7 @@ int clish_shell_load_scheme(clish_shell_t *this, const char *xml_path, const cha
 			lub_string_free(filename);
 		}
 		closedir(dir);
+		dir = NULL;
 	}
 
 /* To don't free memory twice on cleanup */
@@ -197,8 +204,6 @@ int clish_shell_load_scheme(clish_shell_t *this, const char *xml_path, const cha
 	if (!xslt_path)
 		xslt = NULL;
 #endif
-	doc = NULL;
-	dir = NULL;
 	res = 0; /* Success */
 error:
 	lub_string_free(buffer);
@@ -315,7 +320,8 @@ static int process_clish_module(clish_shell_t *shell, clish_xmlnode_t *element,
 static int process_view(clish_shell_t *shell, clish_xmlnode_t *element,
 	void *parent)
 {
-	clish_view_t *view;
+	clish_view_t *view = NULL;
+	clish_view_restore_e restore_e = CLISH_RESTORE_NONE;
 	int res = -1;
 
 	char *name = clish_xmlnode_fetch_attr(element, "name");
@@ -343,12 +349,8 @@ static int process_view(clish_shell_t *shell, clish_xmlnode_t *element,
 	}
 
 	if (restore) {
-		if (!lub_string_nocasecmp(restore, "depth"))
-			clish_view__set_restore(view, CLISH_RESTORE_DEPTH);
-		else if (!lub_string_nocasecmp(restore, "view"))
-			clish_view__set_restore(view, CLISH_RESTORE_VIEW);
-		else
-			clish_view__set_restore(view, CLISH_RESTORE_NONE);
+		restore_e = clish_view_restore_resolve(restore);
+		clish_view__set_restore(view, restore_e);
 	}
 
 	if (access)
@@ -484,7 +486,7 @@ static int process_command(clish_shell_t *shell, clish_xmlnode_t *element,
 #ifdef LEGACY
 	char *lock = clish_xmlnode_fetch_attr(element, "lock");
 	char *interrupt = clish_xmlnode_fetch_attr(element, "interrupt");
-	clish_action_t *action;
+	clish_action_t *action = NULL;
 #endif
 
 	/* Check syntax */
@@ -567,7 +569,7 @@ static int process_command(clish_shell_t *shell, clish_xmlnode_t *element,
 	}
 
 	/* interrupt */
-	if (interrupt) { // Don't change anything if lock is not specified
+	if (interrupt) { // Don't change anything if interrupt is not specified
 		if (lub_string_nocasecmp(interrupt, "true") == 0)
 			clish_action__set_interrupt(action, BOOL_TRUE);
 		else
@@ -602,17 +604,18 @@ error:
 static int process_startup(clish_shell_t *shell, clish_xmlnode_t *element,
 	void *parent)
 {
-	clish_view_t *v = (clish_view_t *) parent;
 	clish_command_t *cmd = NULL;
 	int res = -1;
 
 	char *view = clish_xmlnode_fetch_attr(element, "view");
 	char *viewid = clish_xmlnode_fetch_attr(element, "viewid");
-	char *default_shebang =
-		clish_xmlnode_fetch_attr(element, "default_shebang");
 	char *timeout = clish_xmlnode_fetch_attr(element, "timeout");
 	char *default_plugin = clish_xmlnode_fetch_attr(element,
 		"default_plugin");
+	char *default_shebang = clish_xmlnode_fetch_attr(element,
+		"default_shebang");
+	char *default_expand = clish_xmlnode_fetch_attr(element,
+		"default_expand");
 #ifdef LEGACY
 	char *lock = clish_xmlnode_fetch_attr(element, "lock");
 	char *interrupt = clish_xmlnode_fetch_attr(element, "interrupt");
@@ -631,7 +634,7 @@ static int process_startup(clish_shell_t *shell, clish_xmlnode_t *element,
 	}
 
 	/* create a command with NULL help */
-	cmd = clish_view_new_command(v, "startup", NULL);
+	cmd = clish_command_new("startup", NULL);
 	clish_command__set_internal(cmd, BOOL_TRUE);
 
 	/* reference the next view */
@@ -644,6 +647,10 @@ static int process_startup(clish_shell_t *shell, clish_xmlnode_t *element,
 	if (default_shebang)
 		clish_shell__set_default_shebang(shell, default_shebang);
 
+	if (default_expand)
+		clish_shell__set_default_expand(shell,
+			(lub_string_nocasecmp(default_expand, "true") == 0));
+
 	if (timeout) {
 		unsigned int to = 0;
 		lub_conv_atoui(timeout, &to, 0);
@@ -681,13 +688,17 @@ static int process_startup(clish_shell_t *shell, clish_xmlnode_t *element,
 error:
 	clish_xml_release(view);
 	clish_xml_release(viewid);
+	clish_xml_release(default_plugin);
 	clish_xml_release(default_shebang);
+	clish_xml_release(default_expand);
 	clish_xml_release(timeout);
 #ifdef LEGACY
 	clish_xml_release(lock);
 	clish_xml_release(interrupt);
 #endif
 
+	parent = parent; /* Happy compiler */
+
 	return res;
 }
 
@@ -877,6 +888,7 @@ static int process_action(clish_shell_t *shell, clish_xmlnode_t *element,
 	char *lock = clish_xmlnode_fetch_attr(element, "lock");
 	char *interrupt = clish_xmlnode_fetch_attr(element, "interrupt");
 	char *interactive = clish_xmlnode_fetch_attr(element, "interactive");
+	char *expand = clish_xmlnode_fetch_attr(element, "expand");
 
 	clish_xmlnode_t *pelement = clish_xmlnode_parent(element);
 	char *pname = clish_xmlnode_get_all_name(pelement);
@@ -912,19 +924,46 @@ static int process_action(clish_shell_t *shell, clish_xmlnode_t *element,
 	if (shebang)
 		clish_action__set_shebang(action, shebang);
 
+	/* interactive */
+	if (interactive && lub_string_nocasecmp(interactive, "true") == 0)
+		clish_action__set_interactive(action, BOOL_TRUE);
+
 	/* lock */
-	if (lock && lub_string_nocasecmp(lock, "false") == 0)
-		clish_action__set_lock(action, BOOL_FALSE);
+	// Don't change anything if lock is not specified
+	// Legacy COMMAND's lock attr can set it already
+	// By default lock is true.
+	// Note ACTION is always follows parental COMMAND so this code will
+	// redefine COMMAND settings.
+	if (lock) {
+		if (lub_string_nocasecmp(lock, "false") == 0)
+			clish_action__set_lock(action, BOOL_FALSE);
+		else
+			clish_action__set_lock(action, BOOL_TRUE);
+	}
 
 	/* interrupt */
-	if (interrupt && lub_string_nocasecmp(interrupt, "true") == 0)
-		clish_action__set_interrupt(action, BOOL_TRUE);
+	// Don't change anything if interrupt is not specified
+	// Legacy COMMAND's interrupt attr can set it already
+	// By default lock is false.
+	// Note ACTION is always follows parental COMMAND so this code will
+	// redefine COMMAND settings.
+	if (interrupt) {
+		if (lub_string_nocasecmp(interrupt, "true") == 0)
+			clish_action__set_interrupt(action, BOOL_TRUE);
+		else
+			clish_action__set_interrupt(action, BOOL_FALSE);
+	}
+
+	/* expand */
+	if (expand)
+		clish_action__set_expand(action, lub_tri_from_string(expand));
 
 	clish_xml_release(builtin);
 	clish_xml_release(shebang);
 	clish_xml_release(lock);
 	clish_xml_release(interrupt);
 	clish_xml_release(interactive);
+	clish_xml_release(expand);
 
 	return 0;
 }
@@ -992,7 +1031,7 @@ static int process_namespace(clish_shell_t *shell, clish_xmlnode_t *element,
 		else
 			clish_nspace_create_prefix_cmd(nspace,
 				"prefix",
-				"Prefix for the imported commands.");
+				"Prefix for imported commands.");
 	}
 
 	if (help && lub_string_nocasecmp(help, "true") == 0)
@@ -1161,7 +1200,6 @@ error:
 static int process_wdog(clish_shell_t *shell,
 	clish_xmlnode_t *element, void *parent)
 {
-	clish_view_t *v = (clish_view_t *)parent;
 	clish_command_t *cmd = NULL;
 	int res = -1;
 
@@ -1172,7 +1210,7 @@ static int process_wdog(clish_shell_t *shell,
 	}
 
 	/* Create a command with NULL help */
-	cmd = clish_view_new_command(v, "watchdog", NULL);
+	cmd = clish_command_new("watchdog", NULL);
 #ifdef LEGACY
 	// Legacy watchdog has lockless ACTION
 	clish_action__set_lock(clish_command__get_action(cmd), BOOL_FALSE);
@@ -1183,6 +1221,8 @@ static int process_wdog(clish_shell_t *shell,
 
 	res = process_children(shell, element, cmd);
 error:
+	parent = parent; /* Happy compiler */
+
 	return res;
 }
 
