@@ -21,7 +21,8 @@ typedef struct clish_view_s clish_view_t;
 typedef enum {
 	CLISH_RESTORE_NONE,
 	CLISH_RESTORE_DEPTH,
-	CLISH_RESTORE_VIEW
+	CLISH_RESTORE_VIEW,
+	CLISH_RESTORE_MAX
 } clish_view_restore_e;
 
 #include "lub/list.h"
@@ -34,6 +35,10 @@ int clish_view_compare(const void *clientnode, const void *clientkey);
 void clish_view_delete(void *instance);
 clish_command_t *clish_view_new_command(clish_view_t * instance,
 	const char *name, const char *text);
+bool_t clish_view_insert_command(clish_view_t * instance,
+	clish_command_t *cmd);
+bool_t clish_view_remove_command(clish_view_t * instance,
+	clish_command_t *cmd);
 clish_command_t *clish_view_find_command(clish_view_t * instance,
 	const char *name, bool_t inherit);
 const clish_command_t *clish_view_find_next_completion(clish_view_t * instance,
@@ -62,5 +67,10 @@ _CLISH_GET(view, clish_view_restore_e, restore);
 
 lub_bintree_t * clish_view__get_tree(clish_view_t *instance);
 
+const char *clish_view_restore__get_name(clish_view_restore_e
+	restore);
+clish_view_restore_e clish_view_restore_resolve(const char
+	*restore_name);
+
 #endif				/* _clish_view_h */
 /** @} clish_view */
