@@ -98,18 +98,43 @@ clish_command_t *clish_view_new_command(clish_view_t * this,
 	clish_command_t *cmd = clish_command_new(name, help);
 	assert(cmd);
 
-	/* if this is a command other than the startup command... */
-	if (NULL != help) {
-		/* ...insert it into the binary tree for this view */
-		if (-1 == lub_bintree_insert(&this->tree, cmd)) {
-			/* inserting a duplicate command is bad */
-			clish_command_delete(cmd);
-			cmd = NULL;
-		}
+	/* try to insert the command */
+	if(!clish_view_insert_command(this, cmd)) {
+		/* ignore duplicate */
+		clish_command_delete(cmd);
+		cmd = NULL;
 	}
+
+	/* return */
 	return cmd;
 }
 
+/*--------------------------------------------------------- */
+bool_t clish_view_insert_command(clish_view_t * this,
+	clish_command_t *cmd)
+{
+	/* insert command into the binary tree for this view */
+	if (-1 == lub_bintree_insert(&this->tree, cmd)) {
+		/* duplicate, not inserted */
+		return BOOL_FALSE;
+	}
+	/* set the pview correctly */
+	clish_command__set_pview(cmd, this);
+	/* Return */
+	return BOOL_TRUE;
+}
+
+/*--------------------------------------------------------- */
+bool_t clish_view_remove_command(clish_view_t * this,
+	clish_command_t *cmd)
+{
+	void *found = lub_bintree_find(&this->tree, cmd);
+	/* remove the command from the tree */
+	lub_bintree_remove(&this->tree, cmd);
+	/* return true if found */
+	return found ? BOOL_TRUE : BOOL_FALSE;
+}
+
 /*--------------------------------------------------------- */
 /* This method identifies the command (if any) which provides
  * the longest match with the specified line of text.
@@ -157,24 +182,7 @@ clish_command_t *clish_view_resolve_prefix(clish_view_t * this,
 clish_command_t *clish_view_resolve_command(clish_view_t *this,
 	const char *line, bool_t inherit)
 {
-	clish_command_t *result = clish_view_resolve_prefix(this, line, inherit);
-
-	if (result) {
-		clish_action_t *action = clish_command__get_action(result);
-		clish_config_t *config = clish_command__get_config(result);
-		if (!clish_action__get_script(action) &&
-			(!clish_action__get_builtin(action)) &&
-			(CLISH_CONFIG_NONE == clish_config__get_op(config)) &&
-			(!clish_command__get_param_count(result)) &&
-			(!clish_command__get_viewname(result))) {
-			/* if this doesn't do anything we've
-			 * not resolved a command
-			 */
-			result = NULL;
-		}
-	}
-
-	return result;
+	return clish_view_resolve_prefix(this, line, inherit);
 }
 
 /*--------------------------------------------------------- */
@@ -279,6 +287,7 @@ const clish_command_t *clish_view_find_next_completion(clish_view_t * this,
 void clish_view_insert_nspace(clish_view_t * this, clish_nspace_t * nspace)
 {
 	lub_list_add(this->nspaces, nspace);
+	clish_nspace__set_pview(nspace, this);
 }
 
 /*--------------------------------------------------------- */
@@ -322,3 +331,37 @@ lub_bintree_t * clish_view__get_tree(clish_view_t *inst)
 	assert(inst);
 	return &inst->tree;
 }
+/*--------------------------------------------------------- */
+static const char *restore_names[] = {
+	"none",
+	"depth",
+	"view",
+};
+
+/*--------------------------------------------------------- */
+const char *clish_view_restore__get_name(clish_view_restore_e restore)
+{
+	if (restore >= CLISH_RESTORE_MAX)
+		return NULL;
+
+	return restore_names[restore];
+}
+
+/*--------------------------------------------------------- */
+clish_view_restore_e clish_view_restore_resolve(const char *name)
+{
+	clish_view_restore_e result = CLISH_RESTORE_NONE;
+	unsigned int i = 0;
+
+	if (!name)
+		return CLISH_RESTORE_NONE;
+
+	for (i = 0; i < CLISH_RESTORE_MAX; i++) {
+		if (0 == strcmp(name, restore_names[i])) {
+			result = (clish_view_restore_e)i;
+			break;
+		}
+	}
+
+	return result;
+}
