@@ -369,7 +369,7 @@ static bool_t tinyrl_key_up(tinyrl_t * this, int key)
 	}
 	if (entry) {
 		/* display the entry moving the insertion point
-		 * to the end of the line 
+		 * to the end of the line
 		 */
 		this->line = tinyrl_history_entry__get_line(entry);
 		this->point = this->end = strlen(this->line);
@@ -396,7 +396,7 @@ static bool_t tinyrl_key_down(tinyrl_t * this, int key)
 			this->line = tinyrl_history_entry__get_line(entry);
 		}
 		/* display the entry moving the insertion point
-		 * to the end of the line 
+		 * to the end of the line
 		 */
 		this->point = this->end = strlen(this->line);
 		result = BOOL_TRUE;
@@ -526,8 +526,65 @@ static bool_t tinyrl_key_erase_line(tinyrl_t * this, int key)
 	this = this;
 
 	return BOOL_TRUE;
-}/*-------------------------------------------------------- */
+}
 
+/*-------------------------------------------------------- */
+/* Toggle INSert flag. When INS flag is on then pressing "?" you will get
+ * the "?" itself. When INS flag is off then pressing "?" you will get help.
+ * On each interactive line the INS flag wil be reset. May be it will be used
+ * for another symbols (and hotkeys) later.
+ */
+static bool_t tinyrl_toggle_ins_flag(tinyrl_t *this)
+{
+	if (!this)
+		return BOOL_FALSE;
+
+	if (this->ins_flag)
+		this->ins_flag = BOOL_FALSE;
+	else
+		this->ins_flag = BOOL_TRUE;
+
+	return BOOL_TRUE;
+}
+
+/*-------------------------------------------------------- */
+static bool_t tinyrl_reset_ins_flag(tinyrl_t *this)
+{
+	if (!this)
+		return BOOL_FALSE;
+
+	this->ins_flag = BOOL_FALSE;
+	return BOOL_TRUE;
+}
+
+/*-------------------------------------------------------- */
+bool_t tinyrl_get_ins_flag(tinyrl_t *this)
+{
+	if (!this)
+		return BOOL_FALSE;
+
+	return this->ins_flag;
+}
+
+/*-------------------------------------------------------- */
+/* It's a dirty hack. The function to print help is external but we need
+ * to show help on some escape sequences. So suppose raw help key is
+ * Ctrl+_ (Control_underscore 0x1f KEY_US) execute external function for this
+ * key here.
+ */
+/*
+static bool_t tinyrl_key_help(tinyrl_t *this, int key)
+{
+	if (!this || !this->handlers[KEY_US])
+		return BOOL_FALSE;
+
+	key = key; // Happy compiler
+
+	return this->handlers[KEY_US](this, key);
+}
+*/
+
+/*-------------------------------------------------------- */
 static bool_t tinyrl_escape_seq(tinyrl_t *this, const char *esc_seq)
 {
 	int key = 0;
@@ -556,6 +613,8 @@ static bool_t tinyrl_escape_seq(tinyrl_t *this, const char *esc_seq)
 		result = tinyrl_key_delete(this,key);
 		break;
 	case tinyrl_vt100_INSERT:
+		result = tinyrl_toggle_ins_flag(this);
+		break;
 	case tinyrl_vt100_PGDOWN:
 	case tinyrl_vt100_PGUP:
 	case tinyrl_vt100_UNKNOWN:
@@ -652,6 +711,8 @@ static void tinyrl_init(tinyrl_t * this, FILE * istream, FILE * ostream,
 	this->last_point = 0;
 	this->last_line_size = 0;
 	this->utf8 = BOOL_FALSE;
+	this->machine_interface = BOOL_FALSE;
+	this->ins_flag = BOOL_FALSE;
 
 	/* create the vt100 terminal */
 	this->term = tinyrl_vt100_new(NULL, ostream);
@@ -739,9 +800,20 @@ static void tinyrl_internal_position(const tinyrl_t *this, int prompt_len,
 /* Jump to first free line after current multiline input   */
 void tinyrl_multi_crlf(const tinyrl_t * this)
 {
-	unsigned int line_size = strlen(this->last_buffer);
-	unsigned int line_len = utf8_nsyms(this, this->last_buffer, line_size);
-	unsigned int count = utf8_nsyms(this, this->last_buffer, this->last_point);
+	unsigned int line_size = 0;
+	unsigned int line_len = 0;
+	unsigned int count = 0;
+
+	assert(this);
+	if (!this)
+		return;
+
+	if (tinyrl_is_machine_interface(this))
+		return;
+
+	line_size = strlen(this->last_buffer);
+	line_len = utf8_nsyms(this, this->last_buffer, line_size);
+	count = utf8_nsyms(this, this->last_buffer, this->last_point);
 
 	tinyrl_internal_position(this, this->prompt_len + line_len,
 		- (line_len - count), this->last_width);
@@ -752,11 +824,20 @@ void tinyrl_multi_crlf(const tinyrl_t * this)
 /*----------------------------------------------------------------------- */
 void tinyrl_redisplay(tinyrl_t * this)
 {
-	unsigned int line_size = strlen(this->line);
-	unsigned int line_len = utf8_nsyms(this, this->line, line_size);
-	unsigned int width = tinyrl_vt100__get_width(this->term);
-	unsigned int count, eq_chars = 0;
-	int cols;
+	unsigned int line_size = 0;
+	unsigned int line_len = 0;
+	unsigned int width = 0;
+	unsigned int count = 0;
+	unsigned int eq_chars = 0;
+	int cols = 0;
+
+	// Don't redisplay for non-interactive machine interface
+	if (tinyrl_is_machine_interface(this))
+		return;
+
+	line_size = strlen(this->line);
+	line_len = utf8_nsyms(this, this->line, line_size);
+	width = tinyrl_vt100__get_width(this->term);
 
 	/* Prepare print position */
 	if (this->last_buffer && (width == this->last_width)) {
@@ -860,9 +941,10 @@ static char *internal_readline(tinyrl_t * this,
 	this->buffer_size = strlen(this->buffer);
 	this->line = this->buffer;
 	this->context = context;
+	tinyrl_reset_ins_flag(this);
 
 	/* Interactive session */
-	if (this->isatty && !str) {
+	if (tinyrl__get_isatty(this) && !str) {
 		unsigned int utf8_cont = 0; /* UTF-8 continue bytes */
 		unsigned int esc_cont = 0; /* Escape sequence continues */
 		char esc_seq[10]; /* Buffer for ESC sequence */
@@ -995,7 +1077,7 @@ static char *internal_readline(tinyrl_t * this,
 			lub_string_free(tmp);
 	}
 	/*
-	 * duplicate the string for return to the client 
+	 * duplicate the string for return to the client
 	 * we have to duplicate as we may be referencing a
 	 * history entry or our internal buffer
 	 */
@@ -1121,7 +1203,7 @@ bool_t tinyrl_insert_text(tinyrl_t * this, const char *text)
 }
 
 /*----------------------------------------------------------------------- */
-/* 
+/*
  * A convenience function for displaying a list of strings in columnar
  * format on Readline's output stream. matches is the list of strings,
  * in argv format, such as a list of completion matches. len is the number
@@ -1232,11 +1314,11 @@ bool_t tinyrl_bind_key(tinyrl_t * this, int key, tinyrl_key_func_t * fn)
  * returned array is the substitution for text. The remaining entries
  * are the possible completions. The array is terminated with a NULL pointer.
  *
- * entry_func is a function of two args, and returns a char *. 
+ * entry_func is a function of two args, and returns a char *.
  * The first argument is text. The second is a state argument;
  * it is zero on the first call, and non-zero on subsequent calls.
- * entry_func returns a NULL pointer to the caller when there are no 
- * more matches. 
+ * entry_func returns a NULL pointer to the caller when there are no
+ * more matches.
  */
 char **tinyrl_completion(tinyrl_t * this,
 	const char *line, unsigned int start, unsigned int end,
@@ -1516,6 +1598,16 @@ void tinyrl__set_istream(tinyrl_t * this, FILE * istream)
 /*-------------------------------------------------------- */
 bool_t tinyrl__get_isatty(const tinyrl_t * this)
 {
+	assert(this);
+	if (!this)
+		return BOOL_FALSE;
+
+	// The machine interface can be forced. It means the interaction is not
+	// interactive and stdin/stdout considered as not terminal but just as
+	// a stream. So return fake value.
+	if (tinyrl_is_machine_interface(this))
+		return BOOL_FALSE;
+
 	return this->isatty;
 }
 
@@ -1654,4 +1746,33 @@ void tinyrl__stifle_history(tinyrl_t *this, unsigned int stifle)
 {
 	tinyrl_history_stifle(this->history, stifle);
 }
+
 /*--------------------------------------------------------- */
+void tinyrl_set_machine_interface(tinyrl_t *this)
+{
+	assert(this);
+	if (!this)
+		return;
+
+	this->machine_interface = BOOL_TRUE;
+}
+
+/*--------------------------------------------------------- */
+void tinyrl_set_human_interface(tinyrl_t *this)
+{
+	assert(this);
+	if (!this)
+		return;
+
+	this->machine_interface = BOOL_FALSE;
+}
+
+/*--------------------------------------------------------- */
+bool_t tinyrl_is_machine_interface(const tinyrl_t *this)
+{
+	assert(this);
+	if (!this)
+		return BOOL_FALSE;
+
+	return this->machine_interface;
+}
